@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 from mootdx.consts import HQ_HOSTS, EX_HOSTS, GP_HOSTS
 
-__version__ = '0.3.17'
+__version__ = "0.3.20"
+__author__ = "bopo.wang"
 
 CONFIG = {
     'SERVER': {
