@@ -17,6 +17,7 @@ config.setup()
 
 
 class Quotes(object):
+
     @staticmethod
     def factory(market='std', **kwargs):
         '''
@@ -65,6 +66,7 @@ class StdQuotes(object):
 
         with self.client.connect(*self.bestip):
             symbol = get_stock_markets(symbol)
+            print(symbol)
             result = self.client.get_security_quotes(symbol)
 
             return to_data(result)
@@ -82,8 +84,9 @@ class StdQuotes(object):
         '''
         with self.client.connect(*self.bestip):
             market = get_stock_market(symbol)
-            result = self.client.get_security_bars(
-                int(frequency), int(market), str(symbol), int(start), int(offset))
+            result = self.client.get_security_bars(int(frequency), int(market),
+                                                   str(symbol), int(start),
+                                                   int(offset))
 
             return to_data(result)
 
@@ -110,12 +113,19 @@ class StdQuotes(object):
             stocks = None
 
             for start in tqdm(range(0, counts, 1000)):
-                result = self.client.get_security_list(market=market, start=start)
-                stocks = pandas.concat([stocks, to_data(result)], ignore_index=True) if start > 1 else to_data(result)
+                result = self.client.get_security_list(market=market,
+                                                       start=start)
+                stocks = pandas.concat(
+                    [stocks, to_data(result)],
+                    ignore_index=True) if start > 1 else to_data(result)
 
             return stocks
 
-    def index_bars(self, symbol='000001', frequency='9', start='0', offset='100'):
+    def index_bars(self,
+                   symbol='000001',
+                   frequency='9',
+                   start='0',
+                   offset='100'):
         '''
         获取指数k线
 
@@ -127,8 +137,11 @@ class StdQuotes(object):
         '''
         with self.client.connect(*self.bestip):
             market = get_stock_market(symbol)
-            result = self.client.get_index_bars(
-                frequency=frequency, market=market, code=symbol, start=start, count=offset)
+            result = self.client.get_index_bars(frequency=frequency,
+                                                market=market,
+                                                code=symbol,
+                                                start=start,
+                                                count=offset)
 
             return to_data(result)
 
@@ -142,8 +155,8 @@ class StdQuotes(object):
         '''
         with self.client.connect(*self.bestip):
             market = get_stock_market(symbol)
-            result = self.client.get_minute_time_data(market=market, code=symbol)
-
+            result = self.client.get_minute_time_data(market=market,
+                                                      code=symbol)
             return to_data(result)
 
     def minutes(self, symbol='', date='20191023'):
@@ -157,8 +170,9 @@ class StdQuotes(object):
         '''
         with self.client.connect(*self.bestip):
             market = get_stock_market(symbol)
-            result = self.client.get_history_minute_time_data(
-                market=market, code=symbol, date=date)
+            result = self.client.get_history_minute_time_data(market=market,
+                                                              code=symbol,
+                                                              date=date)
 
             return to_data(result)
 
@@ -174,8 +188,8 @@ class StdQuotes(object):
         '''
         with self.client.connect(*self.bestip):
             market = get_stock_market(symbol)
-            result = self.client.get_transaction_data(
-                int(market), symbol, int(start), int(market))
+            result = self.client.get_transaction_data(int(market), symbol,
+                                                      int(start), int(market))
 
             return to_data(result)
 
@@ -193,8 +207,11 @@ class StdQuotes(object):
         '''
         with self.client.connect(*self.bestip):
             market = get_stock_market(symbol, string=False)
-            result = self.client.get_history_transaction_data(
-                market=market, code=symbol, start=start, count=offset, date=date)
+            result = self.client.get_history_transaction_data(market=market,
+                                                              code=symbol,
+                                                              start=start,
+                                                              count=offset,
+                                                              date=date)
 
             return to_data(result)
 
@@ -224,17 +241,26 @@ class StdQuotes(object):
             result = {}
             market = get_stock_market(symbol, string=False)
 
-            frequency = self.client.get_company_info_category(int(market), symbol)
+            frequency = self.client.get_company_info_category(
+                int(market), symbol)
 
             if name:
                 for x in frequency:
                     if x['name'] == name:
                         return self.client.get_company_info_content(
-                            market=market, code=symbol, filename=x['filename'], start=x['start'], length=x['length'])
+                            market=market,
+                            code=symbol,
+                            filename=x['filename'],
+                            start=x['start'],
+                            length=x['length'])
 
             for x in frequency:
                 result[x['name']] = self.client.get_company_info_content(
-                    market=market, code=symbol, filename=x['filename'], start=x['start'], length=x['length'])
+                    market=market,
+                    code=symbol,
+                    filename=x['filename'],
+                    start=x['start'],
+                    length=x['length'])
             else:
                 pass
 
@@ -280,7 +306,12 @@ class StdQuotes(object):
             result = self.client.get_k_data(symbol, begin, end)
             return to_data(result)
 
-    def index(self, symbol='000001', market=MARKET_SH, frequency='9', start=1, offset=2):
+    def index(self,
+              symbol='000001',
+              market=MARKET_SH,
+              frequency='9',
+              start=1,
+              offset=2):
         '''
         获取指数k线
 
@@ -306,7 +337,9 @@ class StdQuotes(object):
         :return: pd.dataFrame or None
         '''
         with self.client.connect(*self.bestip):
-            result = self.client.get_index_bars(int(frequency), int(market), str(symbol), int(start), int(offset))
+            result = self.client.get_index_bars(int(frequency), int(market),
+                                                str(symbol), int(start),
+                                                int(offset))
             return to_data(result)
 
     def block(self, tofile="block.dat"):
@@ -394,7 +427,8 @@ class ExtQuotes(object):
             result = []
 
             for page in tqdm(range(0, pages)):
-                result += self.client.get_instrument_info(page * 100, (page + 1) * 100)
+                result += self.client.get_instrument_info(
+                    page * 100, (page + 1) * 100)
 
             return to_data(result)
 
@@ -435,7 +469,8 @@ class ExtQuotes(object):
         '''
         market, symbol = self.validate(market, symbol)
         with self.client.connect(*self.bestip):
-            result = self.client.get_history_minute_time_data(market, symbol, date)
+            result = self.client.get_history_minute_time_data(
+                market, symbol, date)
             return to_data(result)
 
     def bars(self, frequency='', market='', symbol='', start='', offset=0):
@@ -452,8 +487,11 @@ class ExtQuotes(object):
         '''
         market, symbol = self.validate(market, symbol)
         with self.client.connect(*self.bestip):
-            result = self.client.get_instrument_bars(
-                frequency=frequency, market=market, code=symbol, start=start, count=offset)
+            result = self.client.get_instrument_bars(frequency=frequency,
+                                                     market=market,
+                                                     code=symbol,
+                                                     start=start,
+                                                     count=offset)
             return to_data(result)
 
     def transaction(self, market=None, symbol='', start=0, offset=1800):
@@ -468,10 +506,18 @@ class ExtQuotes(object):
         '''
         market, symbol = self.validate(market, symbol)
         with self.client.connect(*self.bestip):
-            result = self.client.get_transaction_data(market=market, code=symbol, start=start, count=offset)
+            result = self.client.get_transaction_data(market=market,
+                                                      code=symbol,
+                                                      start=start,
+                                                      count=offset)
             return to_data(result)
 
-    def transactions(self, market=None, symbol='', date='', start=0, offset=1800):
+    def transactions(self,
+                     market=None,
+                     symbol='',
+                     date='',
+                     start=0,
+                     offset=1800):
         '''
         查询历史分笔成交
 
@@ -484,6 +530,9 @@ class ExtQuotes(object):
         '''
         market, symbol = self.validate(market, symbol)
         with self.client.connect(*self.bestip):
-            result = self.client.get_history_transaction_data(
-                market=market, code=symbol, date=date, start=start, count=offset)
+            result = self.client.get_history_transaction_data(market=market,
+                                                              code=symbol,
+                                                              date=date,
+                                                              start=start,
+                                                              count=offset)
             return to_data(result)
